@@ -1,3 +1,4 @@
+import inspect
 import os
 import subprocess
 import logging
@@ -9,9 +10,13 @@ import re
 
 from colorama import Fore
 
-
+import os
+import logging
+import sys
+import importlib
+import importlib.util
 # from .model import get_all_classes_inherited_AIxBlockMLBase
-
+from aixblock_ml.model import AIxBlockMLBase
 
 colorama.init()
 logger = logging.getLogger(__name__)
@@ -24,30 +29,30 @@ def get_args():
         '--root-dir', dest='root_dir', default='.',
         help='Projects root directory')
 
-    parser = argparse.ArgumentParser(description='Label studio')
+    parser = argparse.ArgumentParser(description='AIxBlock')
     subparsers = parser.add_subparsers(dest='command', help='Available commands')
     subparsers.required = True
 
     # init sub-command parser
-    parser_init = subparsers.add_parser('init', help='Initialize Label Studio', parents=[root_parser])
+    parser_init = subparsers.add_parser('init', help='Initialize AIxBlock', parents=[root_parser])
     parser_init.add_argument(
         'project_name',
         help='Path to directory where project state will be initialized')
     parser_init.add_argument(
-        '--script', '--from', dest='script',
+        '--script', '--from', dest='script',default='aixblock_ml/default_configs/model.py:MyModel',
         help='Machine learning script of the following format: /my/script/path:ModelClass')
     parser_init.add_argument(
         '--force', dest='force', action='store_true',
         help='Force recreating the project if exists')
 
     # start sub-command parser
-    parser_start = subparsers.add_parser('start', help='Initialize Label Studio', parents=[root_parser])
+    parser_start = subparsers.add_parser('start', help='Initialize AIxBlock', parents=[root_parser])
     parser_start.add_argument(
         'project_name',
         help='Path to directory where project state will be initialized')
 
     # start deploy to gcp
-    parser_deploy = subparsers.add_parser('deploy', help='Deploy Label Studio', parents=[root_parser])
+    parser_deploy = subparsers.add_parser('deploy', help='Deploy AIxBlock', parents=[root_parser])
     parser_deploy.add_argument(
         'provider',
         help='Provider where to deploy')
@@ -76,7 +81,31 @@ def get_args():
     args, subargs = parser.parse_known_args()
     return args, subargs
 
+def get_all_classes_inherited_AIxBlockMLBase(script_file):
+    names = set()
+    abs_path = os.path.abspath(script_file)
+    module_name = os.path.splitext(os.path.basename(script_file))[0]
+    sys.path.append(os.path.dirname(abs_path))
+    try:
+        module = importlib.import_module(module_name)
+    except ModuleNotFoundError as e:
+        print(Fore.RED + 'Can\'t import module "' + module_name + f'", reason: {e}.\n'
+              'If you are looking for examples, you can find a dummy model.py here:\n' +
+              Fore.LIGHTYELLOW_EX + 'https://wow-ai.com/tutorials/dummy_model.html')
+        module = None
+        exit(-1)
 
+    for name, obj in inspect.getmembers(module, inspect.isclass):
+        print(name)
+        if name == AIxBlockMLBase.__name__:
+            continue
+        if issubclass(obj, AIxBlockMLBase):
+            names.add(name)
+        for base in obj.__bases__:
+            if AIxBlockMLBase.__name__ == base.__name__:
+                names.add(name)
+    sys.path.pop()
+    return list(names)
 def create_dir(args):
     output_dir = os.path.join(args.root_dir, args.project_name)
     if os.path.exists(output_dir) and args.force:
@@ -89,8 +118,9 @@ def create_dir(args):
 
     # extract script name and model class
     if not args.script:
+        args.script = 'default_configs/model.py:MyModel'
         logger.warning('You don\'t specify script path: by default, "./model.py" is used')
-        script_path = 'model.py'
+        script_path = 'model.py:MyModel'
     else:
         script_path = args.script
 
@@ -100,14 +130,14 @@ def create_dir(args):
 
     if model_def_in_path(script_path):
         script_path, model_class = args.script.rsplit(':', 1)
-    # else:
-    #     model_classes = get_all_classes_inherited_AIxBlockMLBase(script_path)
-    #     if len(model_classes) > 1:
-    #         raise ValueError(
-    #             'You don\'t specify target model class, and we\'ve found {num} possible candidates within {script}. '
-    #             'Please specify explicitly which one should be used using the following format:\n '
-    #             '{script}:{model_class}'.format(num=len(model_classes), script=script_path, model_class=model_classes[0]))
-    #     model_class = model_classes[0]
+    else:
+        model_classes = get_all_classes_inherited_AIxBlockMLBase(script_path)
+        if len(model_classes) > 1:
+            raise ValueError(
+                'You don\'t specify target model class, and we\'ve found {num} possible candidates within {script}. '
+                'Please specify explicitly which one should be used using the following format:\n '
+                '{script}:{model_class}'.format(num=len(model_classes), script=script_path, model_class=model_classes[0]))
+        model_class = model_classes[0]
 
     if not os.path.exists(script_path):
         raise FileNotFoundError(script_path)
@@ -121,7 +151,7 @@ def create_dir(args):
     use(script_base_name)
     use('requirements.txt')
     use('README.md')
-
+  
     wsgi_script_file = os.path.join(default_configs_dir, '_wsgi.py.tmpl')
     with open(wsgi_script_file) as f:
         wsgi_script = f.read()
@@ -129,6 +159,7 @@ def create_dir(args):
         script=os.path.splitext(script_base_name)[0],
         model_class=model_class
     )
+    # wsgi_script = wsgi_script.replace("model_class", model_class).replace("script", os.path.splitext(script_base_name)[0])
     wsgi_name = os.path.basename(wsgi_script_file).split('.tmpl', 1)[0]
     with open(os.path.join(output_dir, wsgi_name), mode='w') as fout:
         fout.write(wsgi_script)
